#
# spec file for package monero-gui
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           monero-gui
Version:        0.18.3.1
Release:        1.3
Summary:        The official GUI app for the Monero cryptocurrency
License:        BSD-3-Clause
URL:            https://github.com/monero-project/monero-gui
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5QuickControls2-devel
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_serialization-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libcurl-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgcrypt20
BuildRequires:  libhidapi-devel
BuildRequires:  libminiupnpc-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qttools-devel
BuildRequires:  libsodium-devel
BuildRequires:  libunwind-devel
BuildRequires:  libusb-devel
BuildRequires:  ninja
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  unbound-devel
BuildRequires:  update-desktop-files
BuildRequires:  zeromq-devel
Requires:       graphviz
Requires:       gtk3-tools
Requires:       monero-utils
Requires:       monerod

%description
The official Qt-based GUI wallet app for the privacy-focused Monero cryptocurrency

%prep
%autosetup

%build
%define __builder ninja
export CXXFLAGS="%{optflags} -Wno-sign-compare"
%cmake \
  -DARCH=default \
  -DBUILD_SHARED_LIBS=OFF \
  -DCMAKE_EXE_LINKER_FLAGS="%{?build_ldflags}" \
  -DCMAKE_MODULE_LINKER_FLAGS="%{?build_ldflags}" \
  -DCMAKE_SHARED_LINKER_FLAGS="%{?build_ldflags}" \
  -Wno-dev
%cmake_build

%install
install -D -m 0755 build/bin/monero-wallet-gui %{buildroot}%{_bindir}/monero-wallet-gui
install -D -m 644 images/appicons/16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/monero-gui.png
install -D -m 644 images/appicons/24x24.png %{buildroot}%{_datadir}/icons/hicolor/24x24/apps/monero-gui.png
install -D -m 644 images/appicons/32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/monero-gui.png
install -D -m 644 images/appicons/48x48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/monero-gui.png
install -D -m 644 images/appicons/64x64.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/monero-gui.png
install -D -m 644 images/appicons/96x96.png %{buildroot}%{_datadir}/icons/hicolor/96x96/apps/monero-gui.png
install -D -m 644 images/appicons/128x128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/monero-gui.png
install -D -m 644 images/appicons/256x256.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/monero-gui.png
%suse_update_desktop_file -c %{name} "Monero Wallet" "GUI wallet for the Monero cryptocurrency" monero-wallet-gui monero-gui Finance\;Network\;Qt\;

%files
%license LICENSE
%{_bindir}/monero-wallet-gui
%{_datadir}/icons/hicolor/16x16/apps/monero-gui.png
%{_datadir}/icons/hicolor/24x24/apps/monero-gui.png
%{_datadir}/icons/hicolor/32x32/apps/monero-gui.png
%{_datadir}/icons/hicolor/48x48/apps/monero-gui.png
%{_datadir}/icons/hicolor/64x64/apps/monero-gui.png
%{_datadir}/icons/hicolor/96x96/apps/monero-gui.png
%{_datadir}/icons/hicolor/128x128/apps/monero-gui.png
%{_datadir}/icons/hicolor/256x256/apps/monero-gui.png
%{_datadir}/applications/monero-gui.desktop

%changelog
* Tue Nov 14 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.18.3.1:
  * p2pool: update to v3.8
  * main: fix qml warning
  * cmake: update sodium dll from 23 to 26
  * Revert "DaemonManager.cpp: disable JIT on macOS ARM"
  * workflows: free up diskspace for docker builds
  * docker: update Linux & Windows Qt to 5.15.11
  * build: prepare v0.18.3.1
  * build: prepare v0.18.3.0
  * p2pool: update to v3.7
  * workflows: run flatpak only in main repo
  * docker: update zlib to 1.3
  * p2pool: update to v3.6.2
  * flatpak: Start workflow after release
  * cmake: update libicu to 73
  * flatpak: Add workflow
  * Fixing broken link to Arch linux package repo
  * p2pool: update to v3.5
  * docker: update Linux & Windows Qt to 5.15.10
  * installers/windows/Readme.htm Updated blockchain size and added pruning description
  * deploy: remove libssp
  * docker: update OpenSSL to 1.1.1u
  * WizardSummary: fix seed language and hide during restore
  * TxUtils: add handleOpenAliasResolution func, simplify code
  * DaemonManager.cpp: disable JIT on macOS ARM
  * main: add ARM build tag for auto updater
  * workflows: set default arch for macOS bundle
  * cmake: copy missing boost lib, run codesign
  * README: add mingw-w64-x86_64-pcre for msys2 instructions
  * cmake: add install_name_tool to fix svg rendering
  * p2pool: fix crash without network connection
  * p2pool: add more detailed failure message
  * Prove/Check: clear text fields on wallet close
  * wizard: add Ledger Stax image
  * readme: tweak build instructions
  * Assume untrusted daemon in simple mode
  * qsTr scan tx error
  * Display clear error when user scans older tx via untrusted daemon
  * Update balance after calling scan_tx
* Wed Apr 19 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.18.2.2:
  * build: prepare v0.18.2.2
  * p2pool: update to v3.2
  * docker: fix linux build
  * docker: remove duplicate library
  * README: remove unmaintained debian repo
  * p2pool: update to v3.1
  * wizard: add Ledger Stax
  * remove output blackballing
* Mon Mar  6 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.18.2.0:
  * DaemonManager: remove systemd check
  * cmake: fix windows deploy
  * build: prepare v0.18.2.0
  * wizard: redesign seed page
  * p2pool: Stop p2pool mining on node switch
  * Utils.js simplify ago func
  * p2pool: Restart monerod only when needed and with proper args
  * p2pool: update to v3.0
  * docker: update hidapi to 0.13.1 on linux
  * docker: update Windows and Linux Qt to 5.15.8
  * p2pool: update to v2.7
  * open-wallet: set network type when using file browser
  * Override desktop theming
  * main: skip proxy when setting localhost remote node
  * README: add unbound for Windows
  * workflows: remove unnecessary dependency
  * Sign/Verify: clear text fields on wallet close
  * History: add open folder button after CSV export
  * p2pool: update to 2.6
  * docker: update Qt to 5.15.7
  * Transfer: update mixin, silence warning
  * docker: update zlib on android
  * workflows: verify p2pool hashes
  * deploy: update libicu to 72
  * README: update Debian dependencies
  * main: fix a potential warning
  * DaemonManager: take dataDir into account when sending cmd
  * main: update blockchain size
  * Docker android: avoid gradle auto download
  * Android: disable simple mode
  * Android: hide local node settings
  * Android: hide log tab
  * Android: hide mining tab
  * Android: useRemoteNode default to true
* Wed Jan 18 2023 Andreas Schwab <schwab@suse.de>
- Update constraints for riscv64
* Mon Nov 14 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.18.1.2:
  * build: prepare v0.18.1.2
  * Github workflow android: remove obsolete docker layers
  * Use different colors for different subaccounts
  * Android: disable asking for desktop entry
  * Docker android: update Qt to 5.15.6 (and API level to 29)
  * workflows: fix windows ci deploy
  * Fix behavior when switching nodes
  * Docker android: upgrade base image
  * Docker android: bump libraries
  * Docker android: update SDK and NDK
  * translations from webalte
  * build: prepare v0.18.1.1
  * installer: allow to install on arm64
  * docker: update qt to 5.15.6
  * cmake: update libicu dll version
  * main: add --no-igd to simple mode flags
  * docker: update linux dependencies
  * repo: remove ldns leftovers
  * Dockerfile: fix hash
  * build: prepare v0.18.1.0
  * main: only check mining status when using local node
  * libwalletqt: refresh once on wallet opening
  * trim restore height at info -> change height input
  * Windows installer: Welcome image for 0.18
  * TxUtils: don't show resolve for float
  * README: Update copyright to 2022
  * build: prepare v0.18.0.0
  * docker: update linux and android openssl
  * docker: fix linux build
  * display wallet files with "." in name
  * Updated to p2pool v2.2.1
  * convert nettype to int to return correct rpc port
  * WizardRestoreWallet1: trim whitespaces from seed
  * Updated to p2pool v2.2
  * DaemonManagerDialog: close dialog when GUI is connected
  * oshelper: fix openContainingFolder on Linux
  * Transfer: don't create offline tx before wallet is synced
  * docker: update Qt to 5.15.5
  * translations from weblate
  * Mining: add info to start gui as admin for p2pool installation
  * Use `p2pool` folder for p2pool on Windows
  * Mining: save selected dropdown index
  * SettingsWallet: add scan transaction option
  * libwallet: add scanTransactions function
  * docker: qt 5.15.4
  * Only kill p2pool if we started it
  * qt: replace QRegExp with QRegularExpression
  * qt: remove QTextCodec
  * main: disable setting -platformpluginpath
  * History: fix payment proof button
  * workflows: add caching for docker android
  * js: minimize frameless window when clicking on taskbar icon
  * main: add compile time option to disable updates
  * WizardModeSelection: disable simple mode on Tails
  * Makefile: set CMAKE_BUILD_TYPE to debug for debug target
  * images: update mac icon
  * WizardCreateDevice1: add Ledger Nano S Plus
  * WizardCreateDevice1: set default restore height to 1
  * Wizard: fix stagenet approx blockheight
  * Settings: option to skip stop local node screen
  * main: remove outdated code
* Thu Jun 16 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints for aarch64 to avoid OOM
* Tue Jun  7 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.17.3.2:
  * TxConfirmationDialog: warn high fees
  * build: prepare v0.17.3.2
  * FutureScheduler: delete unused function declarations
  * main: only update fiat price with open wallet
  * Mining: only update mining status when page is open
  * workflows: action-docker-layer-caching v0.0.11
  * cmake: bump windows deploy lib versions
  * workflows: deploy on windows
  * Docker: Update zlib for android
  * Integrate P2Pool
  * Docker: update Qt 5.15.2 -> 5.15.3
  * TitleBar: Remove lock icon on essentials display
  * AddressBook: fix adding new entry
  * Transfer: fix offline signing
  * RemoteNodeDialog: bind ok to return key
  * SettingsWallet: lock wallet on demand
  * Doc: Minimize boost deps in README.md
  * libwalletqt: fix typo in type
  * workflows: fix windows build error
  * settings: bind return key after password change
  * update languages from weblate and add flags
  * bug: reset wallet path on network change
  * Advanced: ReserveProof: Resolve review by selsta
  * Advanced: ReserveProof: Add support for reserve proof
  * WizardRestoreWallet4, WizardCreateWallet4: disable double-click on "Create wallet" button
  * Docker: bump hidapi on Linux
  * cmake: remove including non-existent directory
  * cmake: don't print verbose make
  * cmake: remove unneeded monero_gui_add_library()
* Fri Mar 11 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints for aarch64 to avoid OOM
* Fri Jan 28 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Build portable binaries without -march=native (boo#1100677)
* Tue Jan 25 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.17.3.1:
  * WizardRestoreWallet3: remove unused code
  * WizardHome: restore binding of networkTypeDropdown.currentIndex when selecting an item; display networkTypeDropdown if stagenet or testnet is selected
  * SettingsInfo: translate tx description of "Donate to Monero" button
  * Wizard: display selected network (testnet/stagenet) on "Create a new wallet" header
  * LeftPanel: use correct shortcut modifier for Mac
  * Fixed English mistake in Mining.qml
  * wizard: clear password field after wallet creation
  * update translations
  * README: add more missing macOS dependencies
  * main: add compile time option to disable desktop entry dialog
  * DEPLOY: use correct ARCH
  * build: prepare v0.17.3.1
  * SettingsWallet: improve and translate trusted remote node error message
  * RemoteNodeList: fix trusted daemon icon margin
  * RemoteNodeList: fix qml warning
  * SettingsWallet, SettingsListItem: disable "Rescan wallet balance" buton if wallet is not synced
  * RemoteNodeList: reconnect after editing remote node
  * History: disable payment proof for hardware wallets
  * main: verify if currentWallet is loaded before calling it
  * Settings, Advanced: mirror stack transition when clicking on a button on the left
  * Translations from Weblate
  * WizardCreateDevice1: Use "Restore wallet" instead of "Create wallet" on Next button when restoring
  * main: hide TitleBar when MerchantTitleBar is visible
  * build: prepare v0.17.3.0
  * WizardSummary: use "Mnemonic seed language" instead of "Language"
  * WizardOpenWallet1: new wallet icons; hide "Mainnet" label in simple mode
  * PasswordDialog: display wizard title bar when returning to wizard after canceling password dialog
  * main: hide wallet name in wizard titlebar
  * WizardCreateDevice1: hide advanced options in simple mode
  * WizardAskPassword: clean password fields when clicking on Back button
  * WizardCreateDevice1: reset fields when opening page
  * add `_` to names of fonts
  * change ttf name of `Roboto-Regular` to `Roboto-Regular_`
  * LeftPanel: display full keyboard shortcuts for Windows, Mac, and Linux
  * LabelSubheader: implement tooltip
  * Updated instructions for Gentoo
  * Mining: add buttons/scroll to CPU threads input; improve button labels; set start mining button as primary
  * Transfer: fix button colors, font size, bold; use secondary button for advanced options
  * StandardDropdown: remove bold text in dropdown items
  * README: add missing macOS dependencies
  * AddressBook: fix edit address button tooltip
  * AddressBook: use small StandardButton; adjust buttons alignment/order; remove paste button
  * Account: use StandardButton for "Create new account"
  * zxcvbn: fix buffer overflow
  * Makefile: don't hardcode x86_64 arch
  * remove reference from mattermost
  * Fix typos
  * cmake: don't hardcode x86-64 arch
  * Receive: set maximum length for qr string
  * cmake: remove werror
  * cmake: simplify version, fix tag if git isn't found
  * add flatpak package
  * workflows: add missing dependency, fix mac build
  * AddressBook: add payment request URI prefix to address field placeholder
  * Transfer: add payment request URI prefix to address field placeholder
  * Docker: add missing hash checks
  * Docker: fix missing unbound on Android
  * cmake: don't force -march=x86-64
  * Docker: fix missing unbound on Linux
  * workflows: fix build on windows
  * cmake: cleanup openssl
  * Transfer: print success / error for key images
  * ContextMenu: add Cut, Copy, Delete and Select All
  * qml: use libwalletqt make_uri function
  * libwalletqt: add make_uri function
  * Transfer: add support for outputs import / export
  * WizardAskPassword: add colors to password strength meter; add "Passwords match/do not match" message
  * LineEdit: fix eye button overlap on password field
  * Wallet: import / export output function
  * Add note about GUI releases to README.md
  * Receive: remove highlight of QR code menu if no menu item is hovered
  * Makefile: fix release-linux-armv8
  * TransactionHistory: add description to csv export
  * cmake: cleanup test-libusb-version.c
  * workflows: replace qt download script for macos-bundle
  * cmake: cleanup boost
  * AddressBook: description edits, remove hack
  * cmake: cleanup redundant ccache file
  * build: prepare v0.17.2.3
  * TxKey: fix get / check proof
  * StandardDialog: use secondary color for cancel button
  * InputDialog: use secondary color for cancel Button
  * WizardCreateDevice1: display images; differentiate Ledger Nano X and S; add label to dropdown
  * Receive: implement payment request
  * WizardRestoreWallet4: "Open wallet" -> "Create wallet"; add translation
  * WizardHeader: fix subtitle text width
  * cmake: remove unnecessary steps
  * History: fix transactions missing after midnight
  * Transfer: use defaultFontColor for text cursor when address field is blank
  * AddressBook: add Grab QR code inline button
  * NetworkStatusItem: add tooltip to switch node button; adjust colors of lightning icon, switch node button and network status
  * Account, Receive, RemoteNodeList, SettingsNode: selection indicator in lists
  * README: TOC, update building titles
  * RemoteNodeList: truncate long addresses
  * Tooltip: fix tooltip width
  * openpgp: add missing include
  * Upgrade Font Awesome icons to v5.15.3
  * cmake: fix incorrect rebase
  * cmake: remove unnecessary file globbing
  * WizardWalletInput: red border if error; error messages; remove placeholders; smaller font; icon for browse button
  * SettingsInfo: fix displaying of Graphics mode and Tails on clipboard output
  * WizardOpenWallet1: navigate with keyboard; enable accessibility
  * LanguageSidebar: navigate/select language with keyboard; enable accessibility; selected indicator; remember previous focused item
  * cmake: enable position independent code for quirc
  * Transfer: fix fee label alignment
  * pages: set correct icon fallback opacity
  * TxConfirmationDialog: fix displaying of "<" when using fontMonoRegular
  * qr: scan valid addresses that miss an uri prefix
  * WizardCreateDevice1: move "choose your device" dropdown to the top
  * Transfer: UI changes to description field (use LineEdit, decrease font size, new placeholder)
  * Receive: selected address details on top; QR code click to ampliate/right click to save as image; click on description to edit; display full address; use standard button for "create new address"
  * RemoteNodeList: reduce spacing between icons
  * RemoteNodeList: display shield icon if trusted daemon
  * History: display Payment proof dialog immediately after clicking the button
  * StandardDropdown: use ArrowCursor; remove rotation of dropdownIcon; change background color on mouse hover; smaller text
  * StandardDropdown: remove dots from corners
  * SettingsInfo: add portable mode to wallet mode
  * TitleBar: maximize window when title bar is double clicked
  * StandardDropdown: use ColumnLayout; use same height of LineEdit; include dropdownLabel
  * Transfer: don't overlap inside borders; fix margins
  * Transfer: remove leftMargin of "Address" label
  * TransactionInfo: add isCoinbase and description
  * TransactionHistory: use displayAmount for amount
  * AddressBook: use LineEdit on descriptionLine; add tab/backtab; forceActiveFocus on addressLine; use Enter/Return key to save; cancel/delete buttons
  * SettingsInfo, WizardRestoreWallet1, WizardCreateDevice1: Correct restore height date when typed in wrong format
  * cmake: fix compilation with zxcvbn, always enable
  * main: fixes bug not accepting new restore height
  * History: collapse "Sort & Filter" when user types
  * LineEdit: use ColumnLayout instead of Item (also used in LineEditMulti)
  * History: stay on the same page after editing description
  * AddressBook: add "See transactions" button
  * History: add fontAwesomeFallbackIcon
  * History: change default dates of "Date from" and "Date to" DatePicker components
  * Wizard: set unused wallet name
  * SettingsLog: ScrollBar always visible (except Mac)
  * SettingsLog: fix text color bug on theme switch; new warning and green text colors
  * Slider: use MoneroComponents.TextPlain instead of Text on label
  * StandardDropdown: add FontAwesome fallback icons
  * DatePicker: date input with fixed size; longer animation; move up calendar rectangle
  * SettingsLog: new placeholder text in command field (no commands in translation string)
  * History: close sortAndFilter when exiting Transactions page
  * DatePicker: support mouse wheel to navigate months
  * DatePicker: highlight selected date/today; hide invalid days
  * DatePicker: display currently selected month when opening calendar
  * DatePicker: FontAwesome fallback icons
  * Transfer: add XMR unit on transactions with a single recipient; move "send all" button next to Amount label
  * Transfer: fix y position of recipient elements
  * build: fix typo
  * History: clean search bar inline button
  * AddressBook: add Font Awesome fallback icons
  * Tooltip: fix binding loop
  * History: move cursor to end of search input field after importing address
  * Receive: add tooltip to search transactions button
  * README: freenode -> libera
  * main: set correct size for pruned blockchain
  * main: simplify fiat ticker code
  * main: use Utils.epoch() for epoch
  * main: remove redundant assignment
  * StandardButton: fix warning with fallbackicon
  * workflows: don't use cache on release tag
  * cmake: explicitly link net and common
  * Makefile: Add ppc64le target
  * Transfer: export all key images by default
  * Account: remove "Balance:" label; add XMR; align balances
* Mon Jun  7 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.17.2.2:
  * Implement tooltips in multiple pages and components
  * main: hide/show popups before/after inactivity screen lock
  * AddressBook: highlight background when selecting contact for transfer page
  * Receive: add search transactions button
  * cmake: cleanup hidapi / libusb
  * cmake: move external subdir before -Werror
  * js: fix getApproximateBlockchainHeight (testnet)
* Fri Apr 23 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.17.2.1:
  * cmake: prepare v0.17.2.1
  * Wallet: fix transfer with Qt 5.12
  * without StartupWMClass=monero-wallet-gui gnome-shell users can not add the applications to their favorites
  * cmake: remove typo
  * workflows: test qml of docker compiled apps
  * build: prepare v0.17.2.0
  * SettingsNode: fix icon size
  * docker: build with QtQmlModels plugin
  * SettingsNode: implement multiple remote nodes support
  * support pruning of new databases
  * RemoteNodeEdit: change border color on focus
  * Checkbox: handle Enter/Return/Space keys, change border color on focus
  * Transfer: implement sending to multiple recipients
  * Renamed Norwegian translation file.
  * LeftPanel: drop Advanced submenu items, use NavBar instead
  * DaemonManager: start monerod with '--non-interactive' cli option set
  * Docker: Android - switch to debian:stretch, build CMake from source
  * Navbar: reimplement as a reusable component, drop redundant code
  * Navbar: move to components
  * cmake: sync submodule if DEV_MODE=ON
  * Translations from Weblate
  * TxConfirmationDialog: implement multiple recipients support, layout fixes
  * use preferred colors for DaemonManagerDialog
  * LineEditMulti: right padding, fontFamily, backtab, inline btns vcenter
  * LineEdit: fontFamily and inputPadding properties, fix backtab
  * CheckBox: change opacity to 70%% in disabled state
  * AddressBook: don't alter tx Description on recipient selection
  * Wallet: estimateTransactionFeeAsync - multi dest support
  * OSHelper: Linux - fix isCapsLock memory leak
  * workflows: add py7zr to macos bundle
  * installers/windows: fix typo in readme.htm
  * README: Update the homebrew install instructions
  * Wallet: refactor createTransaction
  * DaemonManager: enable dns block list in simple mode
  * SettingsLog: disable daemon command input in Remote Node mode
  * Utils: fix removeTrailingZeros regression
  * README: MacOS - add libsodium monero dependency
  * Navbar: cleanup layout
  * README: Windows docker builds are reproducible since v0.17.1.9
  * Makefile: support USE_SINGLE_BUILDDIR=OFF without git installed
  * DaemonManager: refactoring - drop singleton usage
  * Subaddress: log account subaddresses refresh error
  * main: restrict max window width/height, fix initial window alignment
  * SettingsLayout: 'Display wallet name in title bar' option
  * Transfer: implement 'Grab QR code from screen' functionality
  * main: fix kraken fiat api
  * workflows: print sha256sum of windows gui
  * remove copy qr uri to clipboard button
  * History: search by receiving address, receiving address label, address book label
  * account/receive: highlight background and text of selected item
  * WizardRestoreWallet1: add view-only option in placeholder of private spend key
* Wed Apr  7 2021 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Thu Jan 21 2021 nopeinomicon@posteo.net
- Update to version 0.17.1.9:
  * build: prepare v0.17.1.9
  * installer: remove high dpi shortcut
  * docker: Windows - use Qt 5.15.2
  * QR-Code-scanner: integrate QUIRC library, implement QrDecoder, drop ZBar
* Sat Jan  2 2021 nopeinomicon@posteo.net
- Update to version 0.17.1.8:
  * build: prepare v0.17.1.8
  * Transfer: updateFromQrCode - fix extra space (empty recipient name)
  * LineEdit: fix padding, fix inline buttons layout, multiple btns support
  * cmake: MacOS - detect ICU link directory (required by Boost.Locale)
  * Transfer: support pasting amount with whitespaces
  * WizardRestoreWallet1: fix mnemonic seed placeholder
* Tue Dec 15 2020 nopeinomicon@posteo.net
- Update to version 0.17.1.7:
  * build: prepare v0.17.1.7
  * Wallet: fix initialization flag handling
  * main: get back "Sending transaction ..." splash
  * Utils: removeTrailingZeros - handle .0* decimal part (i.e. 1.00000)
  * workflows: shorten name
  * main: disable QML cache
  * main: Linux - fix missing askDesktopShortcut setting
  * workflows: bump docker cache action
* Tue Dec  8 2020 nopeinomicon@posteo.net
- Add actual name to .desktop file title
- Added upstream archive url to Source0 in .spec file
- Update to version 0.17.1.6:
  * build: prepare v0.17.1.6
  * Transfer: fix focus, cycle focus between Address, Amount and Send
  * README: update Linux Docker build instructions
  * TxConfirmationDialog: fix keys handling
  * SuccessfulTxDialog: fix keys handling
  * main: Linux - ask to create desktop entry on the first start
  * workflows: print hash for reproducible builds
  * Restore: display red border if invalid seed
* Wed Dec  2 2020 nopeinomicon@posteo.net
- Cleaned up changes file
- Switched to obs_scm over tar_scm in _service file
- Update to version 0.17.1.5:
  * Simple mode: skip syncing nodes
  * Write QML cache to portable folder
  * Linux: enable high DPI support
  * Minor bug fixes
* Sat Nov 21 2020 Emily Roberts <nopeinomicon@posteo.net>
- Second attempt to fix icons, added post-install section to update icon cache
* Mon Nov 16 2020 Emily Roberts <nopeinomicon@posteo.net>
- Fix .desktop icons
* Sun Nov 15 2020 Emily Roberts <nopeinomicon@posteo.net>
- Fix incorrectly named dependencies in .spec file
* Sat Nov 14 2020 nopeinomicon@posteo.net
- Clean .spec file
- Update to version 0.17.1.4:
  * Linux: fix a deadlock on startup
  * Linux: high DPI support removed, will be readded in subsequent release
  * Linux binary is now reproducible (experimental)
  * Simple mode: transaction reliability improvements
  * New transaction confirmation dialog
  * Wizard: minor design changes
  * Linux: high DPI support
  * Fix "can't connect to daemon" issue
  * Minor bug fixes
* Thu Nov 12 2020 Emily Roberts <nopeinomicon@posteo.net>
- Added icons and .desktop files to package
* Wed Nov 11 2020 Emily Roberts <nopeinomicon@posteo.net>
- Add build constraints to avoid out of memory error in build
* Mon Nov  9 2020 Emily Roberts <nopeinomicon@posteo.net>
- Fix spec file install process
- Added reqiurement for monero package
* Sun Nov  8 2020 Emily Roberts <nopeinomicon@posteo.net>
- Initial package release
